﻿using System;

using DevExpress.XtraEditors;
using DevExpress.XtraGrid;
using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                           += Form_Load;
            this.treeList.CustomColumnSort += treeList_CustomColumnSort;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.Columns["MarchSales"].SortMode  = ColumnSortMode.Custom;
            this.treeList.Columns["MarchSales"].SortIndex = 0;

            this.treeList.BestFitColumns();
        }

        #endregion
        #region 트리 리스트 컬럼 커스텀 정렬하기 - treeList_CustomColumnSort(sender, e)

        /// <summary>
        /// 트리 리스트 컬럼 커스텀 정렬하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_CustomColumnSort(object sender, CustomColumnSortEventArgs e)
        {
            if(e.Column.FieldName != "MarchSales")
            {
                return;
            }

            try
            {
                int value1 = Convert.ToInt32(e.NodeValue1);
                int value2 = Convert.ToInt32(e.NodeValue2);

                e.Result = value2 - value1;
            }
            catch
            {
            }
        }

        #endregion
    }
}